/**

  The Initial Developer of the Original Code is
  Matthieu  - http://www.programmation-facile.com/
  Portions created by the Initial Developer are Copyright (C) 2013
  the Initial Developer. All Rights Reserved.

  Contributor(s) :

 */



/**
 * Le Framework de jeux JavaScript Phaser
 *
Phaser v2.0.5 - http://phaser.io - @photonstorm - (c) 2014 Photon Storm Ltd. 
https://github.com/photonstorm/phaser
http://examples.phaser.io/
 */



/**
 * Les variables du jeu
 * 
 */

var game; 

var balance = [];// tableau qui contient les éléments graphiques de la balance et les données associées

var bGrosseBall = false;// est ce que la balle peut grossir

var ball;// l'objet balle


var ballGrowingSpeed = 0.5;// vitesse de grossissement de la balle en pixels par image
var balanceFriction = 400;// limite le mouvement de la balance avec le frottement


var nWidth = 320;
var nHeight = 480;

document.addEventListener("DOMContentLoaded", Main, false); // appel au chargement de la page


/**
 * Fonction principale
 * Appelée au chargement de la page
 * 
 */
function Main()
{
    console.log("Main");

    // creation de la zone de jeu - API Canvas
    game = new Phaser.Game(nWidth, nHeight, Phaser.AUTO, "idGameDiv", {preload:onPreload, create:onCreate, update:onUpdate});
}


/**
 * Préchargement des éléments du jeu
 * 
 * @return {[type]} [description]
 */
function onPreload()
{ 
    game.stage.backgroundColor = '#cccccc';// la couleur de fond du jeu

    game.load.image("balance","assets/icon-balance.png");// charge les éléments graphiques avec leurs identifiants
    game.load.image("ball","assets/tennis_ball.png");
}



/**
 * Création de la scène du jeu,
 * mise en place des graphismes...
 * 
 * @return {[type]} [description]
 */
function onCreate() 
{
    balance[0] = game.add.group();// représente la balance de gauche
    balance[0].weight = 0;// place son poids à 0

    balance[1] = game.add.group();// représente la balance de droite
    balance[1].weight = 0;// place son poids à 0

    // élément graphique représentant la balance de gauche
    var balanceSprite = game.add.sprite(80,240,"balance"); 
    balanceSprite.anchor.x = 0.5;
    balanceSprite.anchor.y = 0.5;
    balance[0].add(balanceSprite);
   
    // élément graphique représentant la balance de droite
    balanceSprite = game.add.sprite(240,240,"balance");
    balanceSprite.anchor.x = 0.5;
    balanceSprite.anchor.y = 0.5;  
    balance[1].add(balanceSprite);

    // dès que l'utilisateur clique sur l'écran, appelle de la fonction addNewBall
    game.input.onDown.add(addNewBall, this);  
}



/**
 * Appelée en continu pendant le jeu
 * 
 * @return {[type]} [description]
 */
function onUpdate() 
{
    // diamètre maximum de la balle
    var nMaxDiametre = 53;

    // fait grossir la balle si c'est possible
    if(bGrosseBall && ball.width < nMaxDiametre)
    {
        ball.width += ballGrowingSpeed;
        ball.height += ballGrowingSpeed;
    }   
}


/**
 * Ajoute une nouvelle balle à l'écran
 * 
 */
function addNewBall()
{
    // créé la nouvelle balle
    ball = game.add.sprite(game.input.worldX, 0, "ball");
    ball.anchor.x = 0.5;
    ball.anchor.y = 0.5;

    // définit la largeur et la hauteur de la balle
    ball.width=1;
    ball.height=1;

    // choix de la balance (gauche ou droite) gauche = 0 sinon droite = 1
    ball.balance = Math.floor(ball.x/(game.width/2));

    balance[ball.balance].add(ball);// ajoute la balle sur la bonne balance

    ball.y = 30 - balance[ball.balance].y;// positionne la balle

    game.input.onUp.add(dropBall, this);// dès que l'utilisateur relache le bouton de la souris appelle   dropBall
    bGrosseBall=true;// autorise le grossissement de la balle
}


/**
 * Effectue l'animation de la chute de la balle
 * 
 * @return {[type]} [description]
 */
function dropBall()
{
    bGrosseBall = false;// empeche le grossissement de la balle

    game.input.onUp.remove(dropBall, this);// supprime l'écouteur sur le relachemet du bouton de la souris 

    // Calcule de la destination de la nouvelle balle - en fonction de la hauteur de l'image balance
    var ballDestination = 185 - ball.height/2;

    // augmente le poids de la balance en fonction de la taille de la balle
    // volume = 4/3*PI*radius^3
    balance[ball.balance].weight += (4/3)*Math.PI * (ball.width/2) * (ball.width/2) * (ball.width/2);

    // création d'une animation type tween pour un effet de rebondissement
    var ballTween = game.add.tween(ball).to({ y: ballDestination}, 2000, Phaser.Easing.Bounce.Out, true);
    ballTween.onComplete.add(adjustBalances, this);// à la fin de la tween, appelle de la fonction
}


/**
 * Mets à jour la position des balances en fonction du poids des balles dessus
 * 
 * @return {[type]} [description]
 */
function adjustBalances()
{
    // détermine la différence de poids entre les balances et division par le frottement
    var weightDifference = (balance[0].weight - balance[1].weight) / balanceFriction;
    
    // limite la différence de poids pour éviter qu'une balance sorte de l'écran
    if( weightDifference > game.height/3 )
        weightDifference = game.height/3;   
    
    if( weightDifference < -game.height/3 )
        weightDifference = -game.height/3;  

    // ajoute des effets de tweens sur les 2 balances
    var balanceTween = game.add.tween(balance[0]).to({ y: weightDifference}, 2000, Phaser.Easing.Quadratic.Out, true);    
    var balanceTween2 = game.add.tween(balance[1]).to({y: -weightDifference}, 2000, Phaser.Easing.Quadratic.Out, true);
}


